@@ -3,9 +3,7 @@ from typing import Callable
 
 from jinja2 import Template
 
-from ..data_request import DataRequest
-from ..dataset import Dataset
-from ..secret import SecretDict
+from baguette_bi.core.data_request import DataRequest
 
 
 def execute_wrapper(fn: Callable):
@@ -22,13 +20,13 @@ class ConnectionMeta(type):
 
 
 class Connection(metaclass=ConnectionMeta):
-    type: str = None
+    type: str
 
     def __init__(self, **details):
-        self.details = SecretDict(details)
+        self.details = details
 
     def dict(self):
-        return {"type": self.type, "details": self.details.dict()}
+        return {"type": self.type, "details": self.details}
 
     def transform_request(self, request: DataRequest):
         request.query = Template(request.query).render(**request.parameters)
@@ -36,18 +34,3 @@ class Connection(metaclass=ConnectionMeta):
 
     def execute(self, request: DataRequest):
         raise NotImplementedError
-
-    def dataset(
-        self,
-        name: str,
-        query: str,
-        storage_connection: "Connection" = None,
-        refresh_interval: int = None,
-    ):
-        return Dataset(
-            name=name,
-            query=query,
-            connection=self,
-            storage_connection=storage_connection,
-            refresh_interval=refresh_interval,
-        )
