@@ -1,8 +1,7 @@
-from baguette_bi.core.data_request import DataRequest
-
 from vega_datasets import data
 
-from .base import Connection
+from baguette_bi.core.connections.base import Connection
+from baguette_bi.core.data_request import DataRequest
 
 
 class VegaDatasetsConnection(Connection):
